# COST03: How do you monitor usage and cost?

## References

- [AWS COST03](https://docs.aws.amazon.com/wellarchitected/latest/framework/cost-03.html)

## Date

2025-11-27

## Focus Area

Cost-Effective Resources

## Best Practices

### COST03-BP01: Configure detailed information sources
Cost and usage reports.

### COST03-BP02: Add organization information to cost and usage
Tagging strategy.

### COST03-BP03: Identify cost attribution categories
Cost allocation.

### COST03-BP04: Establish organization metrics
Cost metrics.

### COST03-BP05: Configure billing and cost management tools
Cost management tools.

### COST03-BP06: Allocate costs based on workload metrics
Usage-based allocation.

## Checklist

- [ ] Cost reports configured
- [ ] Tagging strategy implemented
- [ ] Cost attribution defined
- [ ] Cost metrics established
